<%@ Page Language="c#" %>
<%@ Import Namespace="System.Xml" %>
<%@ Import Namespace="CuteChat" %>

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" >
<html>
<head id="Head1" runat="server">
    <title>DumpMemory</title>
    <meta name="GENERATOR" content="Microsoft Visual Studio .NET 7.1">
    <meta name="CODE_LANGUAGE" content="C#">
    <meta name="vs_defaultClientScript" content="JavaScript">
    <meta name="vs_targetSchema" content="http://schemas.microsoft.com/intellisense/ie5">
</head>
<body ms_positioning="GridLayout">
    <form id="Form1" method="post" runat="server">
    </form>
</body>
</html>

<script runat="server">
protected override void OnLoad(EventArgs e)
{
	base.OnLoad (e);

    Response.ContentType="text/xml";
	XmlTextWriter writer=new XmlTextWriter(Response.OutputStream,Response.ContentEncoding);

	writer.Indentation=1;
	writer.IndentChar='\t';
	writer.Formatting=Formatting.Indented;

	writer.WriteStartDocument();
	writer.WriteStartElement("system");

	ChatSystem.Instance.Dump(writer);

	if(Context.Request.QueryString["HidePortals"]!="1")
	{

		foreach(ChatPortal portal in ChatSystem.Instance.GetStartedPortals())
		{
			lock(portal)
			{
				WritePortal(writer,portal);
			}
		}

	}

	writer.WriteEndElement();
	writer.Flush();

	Response.End();

}

static void WritePortal(XmlTextWriter writer,ChatPortal portal)
{
	writer.WriteStartElement("portal");
	writer.WriteAttributeString("name",portal.Name);

	ChatConnection[] conns=portal.GetAllConnections();

	ChatChannel[] channels=portal.GetStartedChannels();
	Array.Sort(channels,new TypeComparer());

	writer.WriteAttributeString("connections",conns.Length.ToString());
	writer.WriteAttributeString("channels",channels.Length.ToString());

	if(portal.IsMessengerStarted)
	{

		WritePlace(writer,portal.Messenger);

	}

	foreach(ChatChannel channel in channels)
	{
		WritePlace(writer,channel);
	}


	writer.WriteEndElement();
}

static void WritePlace(XmlTextWriter writer,ChatPlace place)
{
	writer.WriteStartElement("place");

	writer.WriteAttributeString("class",place.GetType().Name);

	writer.WriteAttributeString("guid",place.ObjectGuid);
	writer.WriteAttributeString("name",place.PlaceName);
	writer.WriteAttributeString("title",place.PlaceTitle);

	ChatConnection[] conns=place.GetAllConnections();
	writer.WriteAttributeString("connections",conns.Length.ToString());
	
	ChatPlaceItem[] items=place.GetAllItems();
	Array.Sort(items,new TypeComparer());

	writer.WriteAttributeString("items",items.Length.ToString());

	writer.WriteStartElement("connections");

	

	foreach(ChatConnection conn in conns)
	{
		WriteConnection(writer,conn);
	}

	writer.WriteEndElement();

	

	

	writer.WriteStartElement("users");

	foreach(ChatPlaceItem item in items)
	{
		if(item is ChatPlaceUser)
		{
			WriteItem(writer,item);
		}
	}

	writer.WriteEndElement();

	writer.WriteStartElement("items");

	foreach(ChatPlaceItem item in items)
	{
		if(item is ChatPlaceUser)
			continue;
		WriteItem(writer,item);
	}

	writer.WriteEndElement();

	writer.WriteEndElement();
}

static void WriteConnection(XmlTextWriter writer,ChatConnection conn)
{
	writer.WriteStartElement("connection");

	writer.WriteAttributeString("guid",conn.ObjectGuid);
	writer.WriteAttributeString("name",conn.Identity.DisplayName);
	writer.WriteAttributeString("login",conn.Identity.IsAnonymous?"0":"1");
	writer.WriteAttributeString("id",conn.Identity.UniqueId);

	writer.WriteEndElement();
}

static void WriteItem(XmlTextWriter writer,ChatPlaceItem item)
{
	writer.WriteStartElement(item.GetType().Name);

	writer.WriteAttributeString("guid",item.ObjectGuid);
	writer.WriteAttributeString("time",item.ObjectTime.ToString("HH:mm:ss"));

	item.Dump(writer);

	writer.WriteEndElement();
}

class TypeComparer : IComparer
{
	
	public int Compare(object x, object y)
	{
		return x.GetType().FullName.CompareTo(y.GetType().FullName);
	}
}
</script>

